/*global ISBrowser_init ISBrowserBridge ISBrowser_userScripts */
/*eslint no-undef: "error"*/
/*eslint-env browser*/
(function () {
	'use strict';

    var LOG = true;

    if (!String.prototype.endsWith) {
        Object.defineProperty(String.prototype, 'endsWith', {
            value: function(searchString, position) {
                var subjectString = this.toString();
                if (position === undefined || position > subjectString.length) {
                    position = subjectString.length;
                }
                position -= searchString.length;
                var lastIndex = subjectString.indexOf(searchString, position);
                return lastIndex !== -1 && lastIndex === position;
            }
        });
    }

    var SCRIPT_FRAME_FRAGMENT = '#ISBROWSER_FRAME_SCRIPT';
    
    var MSG_FRAME_UNLOAD = 'ISBROWSER_FRAME_UNLOAD';
    var MSG_INJECT = "ISBROWSER_INJECT";

    if (typeof ISBrowser_init === 'function') {
        ISBrowser_init();
        return;
    };

    window.ISBrowser_init = init;
    init();

    function init() {
        initWindow(window);
    }

    function initWindow(win) {
        if (LOG) console.log("initWindow with location " + win.location.href);

        if (win.ISBrowser_initialized) return;
        win.ISBrowser_initialized = true;

        win.addEventListener('message', function(event) {
            if (event.data.type === MSG_FRAME_UNLOAD) {
                if (LOG) console.log("MSG_FRAME_UNLOAD");
                if (LOG) console.log(event);
                tryInitFrames(win);
            }
        });

        win.ISBrowser_inject = function(js) {
            win.eval(js);
            var frames = win.frames;
            if (frames) {
                for (var i = 0; i < frames.length; i++) {
                    try {
                        if (frames[i].ISBrowser_inject) {
                            frames[i].ISBrowser_inject(js);
                        }
                    } catch(e) {

                    }
                }
            }
        };
        fixWindowFeatures(win);
        injectUserScripts(win);
        initDoc(win);
    }

    function initFrameWindow(win) {
        fixWindowFeatures(win);

        win.eval('if (!window.ISBrowser_unloadRegistered) { window.ISBrowser_unloadRegistered = true; window.addEventListener("unload", function() { window.parent.postMessage({ type:"' + MSG_FRAME_UNLOAD + '" }, "*"); }); }');
        
        if (isAboutBlank(win)) {
            if (LOG) console.log("initFrameWindow skipping about:blank " + win.location.href);
            // iframe appena creati hanno una window con location about:blank
            // bisogna attendere che non sia più about:blank per inizializzare il document corretto
            // id dell'interval salvato anche in una variabile locale nel caso in cui si perde accesso alla window per cross-origin
            if (!win.ISBrowser_blankInterval) {
                var interval = setInterval(function() {
                    try {
                        if (!isAboutBlank(win)) {
                            clearInterval(interval);
                            win.ISBrowser_blankInterval = null;
                            initFrameWindow(win);
                        }
                    } catch(e) {
                        // errori origin xss
                        clearInterval(interval);
                        try { win.ISBrowser_blankInterval = null; } catch(e) {}

                    }
                }, 100);
                win.ISBrowser_blankInterval = interval;
            }
            return;
        }

        if (LOG) console.log("initFrameWindow before initWindow " + win.location.href);

        initWindow(win);
    }

    function initFrameDocument(doc) {
        if (doc.ISBrowser_frameInitialized) return;
        if (!isDocReady(doc) && !doc.ISBrowser_waitingFrameReady) {
            doc.ISBrowser_waitingFrameReady = true;
            doc.addEventListener('readystatechange', function() {
                if (isDocReady(doc)) {
                    initFrameDocument(doc);
                }
            });
            return;
        }

        doc.ISBrowser_frameInitialized = true;
        var s = doc.createElement("script");
        s.type = "text/javascript";
        s.src = '//' + doc.location.host + SCRIPT_FRAME_FRAGMENT;
        doc.head.appendChild(s);
    }

    function fixWindowFeatures(win) {
        if (!win.navigator.javaEnabled) {
            win.navigator.javaEnabled = function() {
                return false;
            };
        }
    }

    

    function isDocReady(doc) {
        return doc.readyState == 'interactive' || doc.readyState == 'complete';
    }
    
    function initDoc(win) {
        var doc = win.document;
        if (doc.ISBrowser_initialized) return;
        if (!isDocReady(doc) && !doc.ISBrowser_waitingReady) {
            doc.ISBrowser_waitingReady = true;
            doc.addEventListener('readystatechange', function() {
                if (isDocReady(doc)) {
                    initDoc(win);
                }
            });
            return;
        }

        initIframes(win, doc);
    }

    function injectUserScripts(win) {
        if (typeof ISBrowser_userScripts !== "undefined") {
            if (win.ISBrowser_userScriptInjected) return;
            win.ISBrowser_userScriptInjected = true;

            for (var i = 0; i < ISBrowser_userScripts.length; i++) {
            console.log('inject user script: iteration '+i);
                win.eval(ISBrowser_userScripts[i]); 
            }
        }
    }

    function isAboutBlank(docOrWindow) {
        return docOrWindow.location && docOrWindow.location.href === "about:blank";  
    }

    function nodesContainsIframe(nodes) {
        for (var j = 0; j < nodes.length; ++j) {
            if (nodes[j].nodeName.toLowerCase() === 'iframe') {
                return true;
            }
        }
    }

    function initIframes(win, doc) {
        if (!doc.ISBrowser_iframeObserver && doc.body) {
            doc.ISBrowser_iframeObserver = new MutationObserver(function(mutations) {
                var anyIframe = false;
                for (var i = 0; i < mutations.length; i++) {
                    if (nodesContainsIframe(mutations[i].addedNodes) || nodesContainsIframe(mutations[i].removedNodes)) {
                        anyIframe = true;
                        break;
                    }
                }

                if (anyIframe) {
                    if (LOG) console.log("iframeObserver HAS anyIframe");
                    initIframes(win, doc);
                    tryInitFrames(win);
                }
            });
            doc.ISBrowser_iframeObserver.observe(doc.body, { childList: true, subtree: true });
        }

        var iframeElems = doc.getElementsByTagName('iframe');
        for (var i = 0; i < iframeElems.length; i++) {
            var iframe = iframeElems[i];

            if (!iframe.ISBrowser_initialized) {
                iframe.ISBrowser_initialized = true;
                iframe.setAttribute('allowfullscreen', '');
            }
        }
        tryInitFrames(win);
    }

    function tryInitFrames(win) { 
        var frames = win.frames;
        if (!frames) return;

        if (LOG) console.log(new Date() + " tryInitFrames from " + win.location.href);

        for (var i = 0; i < frames.length; i++) {
            try {
                if (frames[i] !== window) {
                    initFrameWindow(frames[i]);
                }
            } catch(e) {
            }
        }
    }


 })();