(function() {
  'use strict';
  
  if (window.ISBrowser_userInit) return;
  window.ISBrowser_userInit = true;

  if (!window.ISBrowserBridge) {
      try {
          var p = window.parent;
          while (true) {
              if (p === window || !p || window.ISBrowserBridge) break;
              window.ISBrowserBridge = p.ISBrowserBridge;
              p = p.parent;
          }
      } catch(e) {
          console.log(e);
      }
  }

  function isDocReady() {
      return document.readyState == 'interactive' || document.readyState == 'complete';
  }

  function tryFindVideoTypeBySourceTag(video) {
      var type = null;
      var videoChildren = video.children;
      for (var i = 0; i < videoChildren.length; i++) {
          if (videoChildren[i].nodeName != 'SOURCE') continue;
          var source = videoChildren[i];
          if (source.src == video.currentSrc) {
              type = source.type;
          }
      }
      return type;
  }

  function findVideoWithId(videoId) {
      var videos = document.getElementsByTagName('video');
      for (var i = 0; i < videos.length; i++) {
          if (videos[i].ISBrowser_videoId === videoId) {
              return videos[i];
          }
      }
      return null;
  }

  function isVideoPlaying(video) {
       return !!(!video.paused && !video.ended && video.readyState > 2);
  }

  Math.trunc = Math.trunc || function(x) {
      if (isNaN(x)) {
          return NaN;
      }
      if (x > 0) {
          return Math.floor(x);
      }
      return Math.ceil(x);
  };

  function ensureVideoId(video) {
      if (!video.ISBrowser_videoId) {
          video.ISBrowser_videoId = ISBrowserBridge.nextVideoId();
          video.addEventListener('pause', function() {
              ISBrowserBridge.onVideoPaused(video.ISBrowser_videoId);
          });
      }
  }

  function isVideoAd(video) {
      if (typeof ISBrowser_isVideoAd === 'function') {
          return ISBrowser_isVideoAd(video);
      }
      return isFinite(video.duration) && video.duration < 60;
  }

  function isMainVideo(video) {
      if (typeof ISBrowser_isMainVideo === 'function') {
          return ISBrowser_isMainVideo(video);
      }
      return true;
  }

  function goFullscreen(video) {
      if (typeof ISBrowser_goFullscreen === 'function') {
          return ISBrowser_goFullscreen(video);
      }
      if (video && document.webkitCurrentFullScreenElement !== video) {
          video.webkitRequestFullScreen();
      }
  }

  function getVideoType(video) {
      if (typeof ISBrowser_getVideoType === 'function') {
          return ISBrowser_getVideoType(video);
      }
      return tryFindVideoTypeBySourceTag(video);
  }

  function playingListener(e) {
      if (typeof ISBrowserBridge !== 'undefined') {
          if (e.target.nodeName == 'VIDEO') {
              var video = e.target;

              if (!isMainVideo(video)) {
                  return;
              }
              console.log('play pressed');

			var mediaSrcType = window.evaluateElementScrType(video);
    		ISBrowserBridge.onVideoPlaying(mediaSrcType[0], mediaSrcType[1], video.duration);
    		}
      }
  }

  /* Necessario quando il document viene modificato da javascript es. iframe senza src*/
  new MutationObserver(function(mutations) {
      for (var i = 0; i < mutations.length; i++) {
          if (mutations[i].addedNodes && mutations[i].addedNodes.length == 1 && mutations[i].addedNodes[0].nodeName === 'HTML') {
              initDocListeners();
              return;
          }
      }
  }).observe(document, { childList: true });

  function initDocListeners() {
      document.removeEventListener('playing', playingListener, true);
      document.addEventListener('playing', playingListener, true);
  }


  function evaluateSrcTypeVideo(videoElement) {
  console.log('check video');
  var supportedMimeTypes = Array('video/3gpp', 'video/3gpp2', 'video/mp4',
    'video/quicktime', 'video/x-m4v', 'video/webm');

  var typeAttr = "";
  var src = window.getVideoSrc(videoElement);

  console.log('function IDBROWSER_getMediaElementSrcType, src: '+src);
  if (src === '') {
    var sources = videoElement.querySelectorAll('source');
    for (var j = 0; j < sources.length; j++) {
      var mimetype = sources[j].type;
      if (supportedMimeTypes.indexOf(mimetype) > -1) {
        src = sources[j].src;
        if (sources[j].type) {
          typeAttr = sources[j].type;
        }
        break;
      }
    }
  } else if (videoElement.type) {
    typeAttr = videoElement.type;
  }
  return [src, typeAttr];
}
  window.evaluateElementScrType = evaluateSrcTypeVideo;

function getVideoSrcFunction(videoElement)
{
try
{
        console.warn("getvideoSrc");
        if('function' === typeof videojs)
        {
            if(videoElement.classList.contains("vjs-tech"))
            return 'function' === typeof videojs ? videojs(videoElement).currentSrc() : videoElement.currentSrc;
            else
            return videoElement.currentSrc;
        }
	    if('function' === typeof videojs)
		    return 'function' === typeof videojs ? videojs(videoElement).currentSrc() : videoElement.currentSrc;
    	else if('object' === typeof mejs)
    		return 'object' === typeof mejs ? mejs.MediaElementPlayer(videoElement,'').options.mediaUri[0].url : videoElement.currentSrc;
    	else
	    	return videoElement.currentSrc;
	    	}catch(err)
	    	{
	    	return videoElement.currentSrc;
	    	}
	        return videoElement.currentSrc;
}
window.getVideoSrc = getVideoSrcFunction;

initDocListeners();
})();